@@ -1,7 +1,7 @@
 package Getopt::Long::Complete;
 
-our $DATE = '2015-02-15'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2015-04-30'; # DATE
+our $VERSION = '0.25'; # VERSION
 
 use 5.010001;
 use strict;
@@ -48,7 +48,7 @@ sub GetOptionsWithCompletion {
         my ($words, $cword);
         if ($ENV{COMP_LINE}) {
             require Complete::Bash;
-            ($words,$cword) = @{Complete::Bash::parse_cmdline(undef,undef,'=')};
+            ($words,$cword) = @{ Complete::Bash::parse_cmdline() };
         } elsif ($ENV{COMMAND_LINE}) {
             require Complete::Tcsh;
             $shell = 'tcsh';
@@ -110,15 +110,15 @@ Getopt::Long::Complete - A drop-in replacement for Getopt::Long, with shell tab
 
 =head1 VERSION
 
-This document describes version 0.24 of Getopt::Long::Complete (from Perl distribution Getopt-Long-Complete), released on 2015-02-15.
+This document describes version 0.25 of Getopt::Long::Complete (from Perl distribution Getopt-Long-Complete), released on 2015-04-30.
 
 =head1 SYNOPSIS
 
 =head2 First example (simple)
 
 You just replace C<use Getopt::Long> with C<use Getopt::Long::Complete> and your
-program suddenly supports tab completion. This works for most/many programs. For
-example, below is source code for C<delete-user>.
+program suddenly supports tab completion. This works for most/many programs (see
+L</"INCOMPATIBILITIES">. For example, below is source code for C<delete-user>.
 
  use Getopt::Long::Complete;
  my %opts;
@@ -235,6 +235,27 @@ You can use Perl's C<local> to localize the effect.
 
 =head2 $opt_bundling => bool (default: 1)
 
+=head1 INCOMPATIBILITIES
+
+Although you can use Getopt::Long::Complete (GLC) as a drop-in replacement for
+Getopt::Long (GL) most of the time, there are some incompatibilities or
+unsupported features:
+
+=over
+
+=item * GLC does not allow passing configure options during import
+
+GLC only supports running under a specific set of modes anyway: C<bundling>,
+C<no_ignore_case>. Other non-default settings have not been tested and probably
+not supported.
+
+=item * Aside from GetOptions, no other GL functions are currently supported
+
+This include C<GetOptionsFromArray>, C<GetOptionsFromString>, C<Configure>,
+C<HelpMessage>, C<VersionMessage>.
+
+=back
+
 =head1 SEE ALSO
 
 L<Complete::Getopt::Long> (the backend for this module), C<Complete::Bash>,
@@ -256,7 +277,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Getopt-Lon
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Getopt-Long-Complete>.
+Source repository is at L<https://github.com/perlancar/perl-Getopt-Long-Complete>.
 
 =head1 BUGS
 
